ResourceGroupRegistry

Struct ResourceGroupRegistry 

pub struct ResourceGroupRegistry { /* private fields */ }
A registry of resource groups and the statistics for each of them.

Resource groups are user-defined groups which can then be associated with memory and CPU usage in distinct code regions. This mechanism allows for granular resource accounting at the level which makes sense to the application, such as per-thread, per-async task, and so on.

Token guard

When an resource group is registered, an ResourceGroupToken is returned. This token can be used to “enter” the group, which causes memory and CPU usage on the current thread to be attributed to that group. Entering the group returns a drop guard that restores the previously entered group when dropped.

This allows for arbitrarily nested resource groups.

Additionally, Tracked can be used to wrap a Future, attaching it to a specific resource group token. This causes the future to track all memory and CPU usage during polls such that the usage is properly attributed to the resource group.

Resources tracked

Memory usage

In order for memory usage to be tracked, TrackingAllocator must be installed as the global allocator for the process.

CPU usage

CPU usage is automatically tracked if platform support is detected.

Currently, only Linux is supported for CPU usage tracking.

Implementations

Source

impl ResourceGroupRegistry

pub fn global() -> &'static Self

Gets a reference to the global resource group registry.

pub fn allocator_installed() -> bool

Returns true if TrackingAllocator is installed as the global allocator.

pub fn register_resource_group<S>(&self, name: S) -> ResourceGroupToken
where S: AsRef<str>,

Registers a new resource group with the given name.

Returns an ResourceGroupToken that can be used to attribute CPU and memory usage to the newly created resource group.

pub fn visit_resource_groups<F>(&self, f: F)
where F: FnMut(&str, &ResourceStats),

Visits all resource groups in the registry and calls the given closure with their names and statistics.