pub struct ResourceGroupToken { /* private fields */ }Expand description
A token associated with a specific resource group.
Used to attribute allocations and deallocations to a specific group with a scope guard ResourceTrackingGuard, or
through helpers provided by the Track trait.
Implementations
Sourceimpl ResourceGroupToken
impl ResourceGroupToken
Sourcepub fn enter(&self) -> ResourceTrackingGuard<'_>
pub fn enter(&self) -> ResourceTrackingGuard<'_>
Enters this resource group, returning a guard that will exit the resource group when dropped.