ResourceTrackingGuard

Struct ResourceTrackingGuard 

pub struct ResourceTrackingGuard<'a> { /* private fields */ }
A guard representing an resource group which has been entered.

When the guard is dropped, the resource group will be exited and the previously entered resource group will be restored.

This is returned by the ResourceGroupToken::enter method.