pub struct ResourceStats { /* private fields */ }Expand description
Statistics for an resource group.
Implementations
Sourceimpl ResourceStats
impl ResourceStats
Sourcepub fn has_allocated(&self) -> bool
pub fn has_allocated(&self) -> bool
Returns true if the given group has allocated any memory at all.
Sourcepub fn snapshot_delta(
&self,
previous: &ResourceStatsSnapshot,
) -> ResourceStatsSnapshot
pub fn snapshot_delta( &self, previous: &ResourceStatsSnapshot, ) -> ResourceStatsSnapshot
Captures a snapshot of the current statistics based on the delta from a previous snapshot.
This can be used to keep a single local snapshot of the last delta, and then both track the delta since that snapshot, as well as update the snapshot to the current statistics.
Callers should generally create their snapshot via ResourceStatsSnapshot::empty and then use this method
to get their snapshot delta, utilize those delta values in whatever way is necessary, and then merge the
snapshot delta into the primary snapshot via ResourceStatsSnapshot::merge to make it current.